@@ -1,8 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- *  Authors: Rodrigo Moya <rodrigo@novell.com> 
+ *  Authors: Rodrigo Moya <rodrigo@novell.com>
  *           Philip Van Hoof <pvanhoof@gnome.org>
- *           
+ *
  *  Copyright 2004 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -25,12 +25,8 @@
 #endif
 #include <glib.h>
 #include <glib/gi18n.h>
-#ifdef USE_GTKFILECHOOSER
-#  include <gtk/gtkfilechooser.h>
-#  include <gtk/gtkfilechooserdialog.h>
-#else
-#  include <gtk/gtkfilesel.h>
-#endif
+#include <gtk/gtkfilechooser.h>
+#include <gtk/gtkfilechooserdialog.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkstock.h>
@@ -52,7 +48,7 @@ display_error_message (GtkWidget *parent, const char *message)
 {
 	GtkWidget *dialog;
 
-	dialog = gtk_message_dialog_new (GTK_WINDOW (parent), 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (parent), 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", message);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -72,16 +68,16 @@ insert_tz_comps (icalparameter *param, void *cb_data)
 	GError *error = NULL;
 
 	tzid = icalparameter_get_tzid (param);
-	
+
 	if (g_hash_table_lookup (tdata->zones, tzid))
 		return;
-	
+
 	if (!e_cal_get_timezone (tdata->ecal, tzid, &zone, &error)) {
 		g_warning ("Could not get the timezone information for %s :  %s \n", tzid, error->message);
 		g_error_free (error);
 		return;
 	}
-	
+
 	tzcomp = icalcomponent_new_clone (icaltimezone_get_component (zone));
 	g_hash_table_insert (tdata->zones, (gpointer) tzid, (gpointer) tzcomp);
 }
@@ -101,7 +97,7 @@ do_save_calendar_ical (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSourc
 	GList *objects;
 	icalcomponent *top_level = NULL;
 	GnomeVFSURI *uri;
-	gboolean doit = TRUE;	
+	gboolean doit = TRUE;
 
 	primary_source = e_source_selector_peek_primary_selection (target->selector);
 
@@ -109,7 +105,7 @@ do_save_calendar_ical (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSourc
 		return;
 
 	/* open source client */
-	source_client = auth_new_cal_from_source (primary_source, type);
+	source_client = (ECal*) auth_new_cal_from_source (primary_source, type);
 	if (!e_cal_open (source_client, TRUE, &error)) {
 		display_error_message (gtk_widget_get_toplevel (GTK_WIDGET (target->selector)), error->message);
 		g_object_unref (source_client);
@@ -131,7 +127,7 @@ do_save_calendar_ical (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSourc
 
 		while (objects != NULL) {
 			icalcomponent *icalcomp = objects->data;
-		
+
 			icalcomponent_foreach_tzid (icalcomp, insert_tz_comps, &tdata);
 			icalcomponent_add_component (top_level, icalcomp);
 
@@ -146,7 +142,7 @@ do_save_calendar_ical (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSourc
 
 		/* save the file */
 		uri = gnome_vfs_uri_new (dest_uri);
-	
+
 		result = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_READ);
 		if (result == GNOME_VFS_OK)
 			doit = e_error_run(GTK_WINDOW(gtk_widget_get_toplevel (GTK_WIDGET (target->selector))),
@@ -161,18 +157,18 @@ do_save_calendar_ical (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSourc
 						       gnome_vfs_result_to_string (result));
 					}
 			}
-	
+
 			if (result == GNOME_VFS_OK) {
 				char *ical_str;
 				GnomeVFSFileSize bytes_written;
-	
+
 				ical_str = icalcomponent_as_ical_string (top_level);
 				if ((result = gnome_vfs_write (handle, (gconstpointer) ical_str, strlen (ical_str), &bytes_written))
 				    != GNOME_VFS_OK) {
 					display_error_message (gtk_widget_get_toplevel (GTK_WIDGET (target->selector)),
 								       gnome_vfs_result_to_string (result));
 				}
-	
+
 				gnome_vfs_close (handle);
 			}
 		}
